/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.banking.ri.currencydir;

import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

class XMLCurrencyDirectoryBundle
{

  /** Singleton instance. */
  private static final XMLCurrencyDirectoryBundle instance =
    new XMLCurrencyDirectoryBundle();

  /** Creates a new {@code XMLCurrencyDirectoryBundle} instance. */
  XMLCurrencyDirectoryBundle()
  {
    this.getMessage ( "notMonitoringWarning", Locale.getDefault() );
    this.getMessage ( "monitoringInfo", Locale.getDefault() );
    this.getMessage ( "noJAXPValidationWarning", Locale.getDefault() );
    this.getMessage ( "changeInfo", Locale.getDefault() );
  }

  /**
   * Gets the {@code XMLCurrencyDirectoryBundle} singleton.
   *
   * @return the {@code XMLCurrencyDirectoryBundle} singleton.
   */
  static XMLCurrencyDirectoryBundle getInstance()
  {
    return instance;
  }

  /**
   * Gets the text of the message with key {@code "notMonitoringWarning"}.
   *
   * @return <pre>
   * {0} cannot be monitored. {1}</pre>
   */
  String getNotMonitoringWarningText ( final Locale locale )
  {
    return this.getMessage ( "notMonitoringWarning", locale );
  }

  /**
   * Gets the message with key {@code "notMonitoringWarning"}.
   *
   * @return <pre>
   * {0} cannot be monitored. {1}</pre>
   */
  MessageFormat getNotMonitoringWarningMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "notMonitoringWarning", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "monitoringInfo"}.
   *
   * @return <pre>
   * Monitoring {0} for changes.</pre>
   */
  String getMonitoringInfoText ( final Locale locale )
  {
    return this.getMessage ( "monitoringInfo", locale );
  }

  /**
   * Gets the message with key {@code "monitoringInfo"}.
   *
   * @return <pre>
   * Monitoring {0} for changes.</pre>
   */
  MessageFormat getMonitoringInfoMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "monitoringInfo", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "noJAXPValidationWarning"}.
   *
   * @return <pre>
   * No JAXP validation available. {0}</pre>
   */
  String getNoJAXPValidationWarningText ( final Locale locale )
  {
    return this.getMessage ( "noJAXPValidationWarning", locale );
  }

  /**
   * Gets the message with key {@code "noJAXPValidationWarning"}.
   *
   * @return <pre>
   * No JAXP validation available. {0}</pre>
   */
  MessageFormat getNoJAXPValidationWarningMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "noJAXPValidationWarning", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "changeInfo"}.
   *
   * @return <pre>
   * {0} changed.</pre>
   */
  String getChangeInfoText ( final Locale locale )
  {
    return this.getMessage ( "changeInfo", locale );
  }

  /**
   * Gets the message with key {@code "changeInfo"}.
   *
   * @return <pre>
   * {0} changed.</pre>
   */
  MessageFormat getChangeInfoMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "changeInfo", locale ), locale );
  }

  /**
   * Gets a message for a given key and locale.
   *
   * @param key the key of the message to return.
   * @param locale the locale of the message.
   *
   * @return message for {@code key} using {@code locale}.
   */
  private String getMessage( final String key, Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return ResourceBundle.getBundle( "org/jdtaus/banking/ri/currencydir/XMLCurrencyDirectory",
                                     locale ).getString( key );

  }
}
